Module PgcConsts

    '! \name ConstsSec
    '! Constants section
    '!@{

    '! Version
    Public Const PGC_API_VERSION As String = "1.68.170829" '!< Version

    '! Error codes
    Public Enum PgcErrs
        PGC_ERR_NONE = 0 '!< No error
        PGC_ERR_NONE_ASYNC = -1 '!< No Error, async
        PGC_ERR_NONE_FIRST = -11 '!< No Error, first
        PGC_ERR_NONE_LAST = -12 '!< No Error, last
        PGC_ERR_NONE_MARKER = -100 '!< No Error, marker
        PGC_ERR_GENERAL = -101 '!< General error
        PGC_ERR_NOTSUPPORTED = -102 '!< Not supported
        PGC_ERR_PARAM_INVALID = -111 '!< Parameter invalid
        PGC_ERR_SVC_NOTFOUND = -121 '!< Service Not found
        PGC_ERR_SVC_REGISTERFAILED = -122 '!< Register-service failed
        PGC_ERR_CONN_NOTFOUND = -201 '!< Connection Not found
        PGC_ERR_CONN_INITFAILED = -202 '!< Connection-initialize failed
        PGC_ERR_CONN_OPTNOTFOUND = -203 '!< Connection option not found
        PGC_ERR_CONN_ALREADYCONNECTED = -211 '!< Connection already connected
        PGC_ERR_CONN_ALREADYDISCONNECTED = -212 '!< Connection already disconnected
        PGC_ERR_CONN_NOTCONNECTED = -213 '!< Connection Not connected
        PGC_ERR_CONN_CBKNOTREGISTERED = -221 '!< Connection callback Not registered
        PGC_ERR_CONN_ALREADYLISTENING = -231 '!< Connection already listening
        PGC_ERR_CONN_NOTLISTENING = -232 '!< Connection Not listening
        PGC_ERR_SESS_NOTFOUND = -301 '!< Session Not found
        PGC_ERR_SESS_INITFAILED = -302 '!< Session-initialize failed
        PGC_ERR_SESS_MSGCNTINVALID = -311 '!< Session message count invalid
        PGC_ERR_SESS_MSGCNTALREADYSET = -312 '!< Session message count already set
        PGC_ERR_SESS_NOTSOURCE = -321 '!< Session Not in source state
        PGC_ERR_MSG_NOTFOUND = -401 '!< Message Not found
        PGC_ERR_MSG_IDXOUTOFBOUND = -402 '!< Message index out of bound
        PGC_ERR_MSG_FIELDNOTFOUND = -403 '!< Message field Not found
        PGC_ERR_MSG_OBJINVALID = -404 '!< Message object invalid
        PGC_ERR_MSG_SIZEINVALID = -405 '!< Message size invalid
        PGC_ERR_MSG_KEYINVALID = -406 '!< Message key invalid
        PGC_ERR_MSG_WRITEFAILED = -411 '!< Write-message failed
        PGC_ERR_NET_URLINVALID = -501 '!< Network URL invalid
        PGC_ERR_NET_REFINVALID = -502 '!< Network reference invalid
        PGC_ERR_NET_INITFAILED = -503 '!< Initialize-network failed
        PGC_ERR_NET_INFONOTFOUND = -504 '!< Network info Not found
        PGC_ERR_NET_STSNOTFOUND = -505 '!< Network status/statistics not found
        PGC_ERR_NET_CONNECTFAILED = -511 '!< Network-connect failed
        PGC_ERR_NET_HANDSHAKEFAILED = -512 '!< Network-handshake failed
        PGC_ERR_NET_DISCONNECTFAILED = -513 '!< Network-disconnect failed
        PGC_ERR_NET_SENDFAILED = -521 '!< Network-send failed
        PGC_ERR_NET_RECVFAILED = -522 '!< Network-receive failed
        PGC_ERR_NET_FLUSHFAILED = -523 '!< Network-flush failed
        PGC_ERR_NET_PERFORMFAILED = -524 '!< Network-perform failed
        PGC_ERR_NET_TIMEDOUT = -531 '!< Network timed out
        PGC_ERR_NET_LISTENFAILED = -541 '!< Network-listen failed
        PGC_ERR_NET_UNLISTENFAILED = -542 '!< Network-unlisten failed
        PGC_ERR_NET_CLOSED = -551 '!< Network-closed
        PGC_ERR_EXT_IDINVALID = -10101 '!< Ext : ID invalid
        PGC_ERR_EXT_KEYINVALID = -10102 '!< Ext : Key invalid
        PGC_ERR_EXT_TAGINVALID = -10103 '!< Ext: Tag invalid
        PGC_ERR_EXT_PWDINVALID = -10111 '!< Ext: password invalid
        PGC_ERR_EXT_METHODINVALID = -10121 '!< Ext: method invalid
        PGC_ERR_EXT_IDNOTFOUND = -10201 '!< Ext: ID Not found
        PGC_ERR_EXT_KEYNOTFOUND = -10202 '!< Ext: Key Not found
        PGC_ERR_EXT_TAGNOTFOUND = -10203 '!< Ext: Tag Not found
        PGC_ERR_EXT_IDXOUTOFBOUND = -10304 '!< Ext: Index out Of bound
        PGC_ERR_EXT_PWDNOTMATCHED = -10411 '!< Ext: Password Not matched
        PGC_ERR_EXT_ALREADYDONE = -10701 '!< Ext: Already done
        PGC_ERR_END = -99999 '!< Err : End
    End Enum

    '! Data types
    Public Enum PgcTypes
        PGC_TYPE_NULL = 0   '!< Null; Unknown
        PGC_TYPE_STR = 101 '!< String
        PGC_TYPE_NUM = 102 '!< Number
        PGC_TYPE_BOOL = 103 '!< Boolean
        PGC_TYPE_DATE = 111 '!< Date/time
        PGC_TYPE_INT = 121 '!< Integer
        PGC_TYPE_AMT = 122 '!< Amount
        PGC_TYPE_OBJ = 201 '!< Object
        PGC_TYPE_ARR = 202  '!< Array
    End Enum

    '! Timeout Indicators (used in the nTimeout field in NewConn function)
    Public Enum PgcTimeoInds
        PGC_TIMEO_DEF = 0    '!< Default
        PGC_TIMEO_API = -101 '!< API: 5 secs
        PGC_TIMEO_API_LL = -102 '!< API with low latency: 2 secs
        PGC_TIMEO_TXN = -111 '!< Transaction: 10 secs
        PGC_TIMEO_TXN_UI = -113 '!< Transaction with UI: 2 mins
        PGC_TIMEO_BATCH = -121  '!< Batch: 5 mins
        PGC_TIMEO_MSG = -131  '!< Message: 15 secs
        PGC_TIMEO_MSG_LL = -132  '!< Message with low latency: 5 secs
        PGC_TIMEO_FILE = -141 '!< File: 2 hrs
    End Enum

    '! Message operation targets (used in the nMsgCnt field in NewSess function)
    Public Enum PgcMsgOpTgts
        PGC_MSGOP_REGULAR = 1   '!< Regular message
        PGC_MSGOP_SESSDEF = -101 '!< Session default message
    End Enum

    '!@}


End Module
